##
##  fzf.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_fzf_base  0.53.0
%define       V_fzf_snap  20240607

#   package information
Name:         fzf
Summary:      Fuzzy File Searching
URL:          https://github.com/junegunn/fzf/
Vendor:       Junegunn Choi
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Filesystem
License:      MIT
Version:      %{V_fzf_base}.%{V_fzf_snap}
Release:      20240607

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/fzf/fzf-%{V_fzf_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101, rsync

%description
    fzf(1) is a general-purpose command-line fuzzy finder.

%track
    prog fzf = {
        version   = %{V_fzf_base}
        url       = https://github.com/junegunn/fzf/releases
        regex     = tree/(\d+\.\d+\.\d+)
    }

%prep
    %setup -q -n fzf

%build
    #   build program
    (   export GOPATH=`pwd`
        cd $GOPATH/src/github.com/junegunn/fzf
        go build -v -o bin/fzf main.go
    ) || exit $?

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1 \
        $RPM_BUILD_ROOT%{l_prefix}/share/fzf

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/junegunn/fzf/bin/fzf \
        $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 755 \
        -e 's;#!/usr/bin/env bash;#!%{l_bash};' \
        src/github.com/junegunn/fzf/bin/fzf-tmux \
        $RPM_BUILD_ROOT%{l_prefix}/bin/

    #   install manual page
    %{l_shtool} install -c -m 644 \
        src/github.com/junegunn/fzf/man/man1/fzf.1 \
        src/github.com/junegunn/fzf/man/man1/fzf-tmux.1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1/

    #   install aux files
    %{l_shtool} install -c -m 644 \
        src/github.com/junegunn/fzf/plugin/* \
        src/github.com/junegunn/fzf/shell/* \
        $RPM_BUILD_ROOT%{l_prefix}/share/fzf/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

